# Predictive Test Selection

**Predictive Test Selection** uses machine learning to select the right tests to run for a specific code change. This unlocks the ability to run a much smaller set of tests at various points in your software development lifecycle, accelerating delivery.

With Predictive Test Selection, Launchable actually tells your test runner exactly which tests to run based on data from past test runs and the changes being tested:

![](<../../.gitbook/assets/subsetting diagram@2x.png>)
